@@ -1,3 +1,26 @@
+// Copyright (c) 2006-2008 Andreas Kloeckner
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to
+// deal in the Software without restriction, including without limitation the
+// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+// sell copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+// 
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+// IN THE SOFTWARE.
+
+
+
+
 #include <tstring.h>
 #include <tag.h>
 #include <tag.h>
@@ -183,22 +206,6 @@ BOOST_PYTHON_MODULE(_tagpy)
     .value("UTF16LE", String::UTF16LE)
     ;
 
-  {
-    typedef FileRef cl;
-    class_<cl>(
-        "FileRef", 
-        init<const char *, optional<bool, AudioProperties::ReadStyle> >())
-      .def("tag", &cl::tag, return_internal_reference<>())
-      .def("audioProperties", &cl::audioProperties, 
-          return_internal_reference<>())
-      .def("file", &cl::file, return_internal_reference<>())
-      .DEF_SIMPLE_METHOD(isNull)
-      .DEF_SIMPLE_METHOD(save)
-      .DEF_SIMPLE_METHOD(defaultFileExtensions)
-      .staticmethod("defaultFileExtensions")
-      ;
-  }
-
   exposeID3();
   exposeRest();
 }
